from amoChatApi.AbstractMessage import Message
class TextMessage(Message):
    def __init__(self, text:str = None):
        self._text = text
    def get_json(self):
        json = {
            "type": "text",
            "text": self._text
        }
        return json
    def set_text(self, text:str):
        self._text = text
    def get_type(self):
        return "text"



from amoApi.amoEntities.BaseEnity import BaseEnity
import json


class User(BaseEnity):

    def __init__(self, api = None, json = {}):
        self._api = api
        self._json = json
    def get_json(self):
        return self._json
    def get_id(self):
        return self._json.get("id")
    def set_id(self, id:int):
        self._json["id"] = id
    def get_name(self):
        return self._json.get("name")
    def set_name(self, name:str):
        self._json["name"] = name
    def get_email(self):
        return self._json.get("email")
    def set_email(self, email:str):
        self._json["email"] = email
    def get_rights(self):
        return self._json.get("rights")


from amoApi.amoEntities.BaseEnity import BaseEnity


class Tag(BaseEnity):
    def __init__(self, api = None, json = {}):
        self._api = api
        self._json = json
    def get_json(self):
        return self._json
    def get_id(self):
        return self._json.get("id")
    def set_id(self, id:int):
        self._json["id"] = id
    def get_name(self):
        return self._json.get("name")
    def set_name(self, name:str):
        self._json["name"] = name
    def get_color(self):
        return self._json.get("color")
    def set_color(self, color:str):
        self._json["color"] = color


from amoApi.amoEntities.BaseEnity import BaseEnity


class Company(BaseEnity):
    def __init__(self, api = None, json = {}):
        self._api = api
        self._json = json
    def get_json(self):
        return self._json
    def from_json(self, json):
        self._json = json
    json = property(get_json, from_json)
    def get_id(self):
        return self._json.get("id")
    def set_id(self, id:int):
        self._json["id"] = id
    id = property(get_id, set_id)
    def get_name(self):
        return self._json.get("name")
    def set_name(self, name):
        self._json["name"] = name
    name = property(get_name, set_name)
    def get_responsible_user_id(self):
        return self._json.get("responsible_user_id")
    def set_responsible_user_id(self, id:int):
        self._json["responsible_user_id"] = id
    responsible_user_id = property(get_responsible_user_id, set_responsible_user_id)
    def get_group_id(self):
        return self._json.get("group_id")
    def set_group_id(self, id:int):
        self._json["group_id"] = id
    group_id = property(get_group_id, set_group_id)
    def get_created_by(self):
        return self._json.get("created_by")
    def set_created_by(self, id):
        self._json["created_by"] = id
    created_by = property(get_created_by, set_created_by)
    def get_updated_by(self):
        return self._json.get("updated_by")
    def set_updated_by(self, id:int):
        self._json["updated_by"] = id
    updated_by = property(get_updated_by, set_updated_by)
    def get_created_at(self):
        return self._json.get("created_at")
    def set_created_at(self, timestamp:int):
        self._json["created_at"] = timestamp
    created_at = property(get_created_at, set_created_at)
    def get_updated_at(self):
        return self._json.get("updated_at")
    def set_updated_at(self, timestamp:int):
        self._json["updated_at"] = timestamp
    updated_at = property(get_updated_at, set_updated_at)
    def get_closest_task_at(self):
        return self._json.get("closest_task_at")
    def set_closest_task_at(self, timestamp:int):
        self._json["closest_task_at"] = timestamp
    closest_tast_at = property(get_closest_task_at, set_closest_task_at)
    def get_is_deleted(self):
        if self._json.get("is_deleted"):
            return self._json.get("is_deleted")
        else:
            return False
    def set_is_deleted(self, state:bool):
        self.json["is_deleted"] = state
    is_deleted = property(get_is_deleted, set_is_deleted)
    def get_account_id(self):
        return self._json.get("account_id")
    def set_account_id(self, id:int):
        self._json["account_id"] = id
    account_id = property(get_account_id, set_account_id)
    def get_tags(self):
        from amoApi.amoEntities.Tag import Tag
        if self._json["_embedded"].get("tags") is None:
            return []
        return [Tag(self._api, json_tag) for json_tag in self._json["_embedded"]["tags"]]

    def get_contacts(self):
        from amoApi.amoEntities.Contact import Contact
        if self._json["_embedded"].get("contacts") is None:
            return []
        return [Contact(self._api, json_contact) for json_contact in self._json["_embedded"]["contacts"]]

    def get_leads(self):
        from amoApi.amoEntities.Lead import Lead
        if self._json["_embedded"].get("leads") is None:
            return []
        return [Lead(self._api, json_lead) for json_lead in self._json["_embedded"]["leads"]]


import json
from typing import List
from amoApi.amoEntities.BaseEnity import BaseEnity


class Contact(BaseEnity):
    def __init__(self, api = None, json_contact:json = {}):
        self._json = json_contact
        self._api = api

    def from_json(self, json_contact:json):
        self._json = json_contact
        return self

    def set_id(self, id:str):
        self._json["id"] = id

    def get_id(self):
        return self._json.get("id")

    def set_name(self, name:str):
        self._json["name"] = name

    def get_name(self):
        return self._json.get("name")

    def set_first_name(self, first_name:str):
        self._json["first_name"] = first_name

    def get_first_name(self):
        return self._json.get("first_name")

    def set_last_name(self, last_name:str):
        self._json["last_name"] = last_name

    def get_last_name(self):
        return self._json.get("last_name")

    def set_responsible_user_id(self, responsible_user_id:str):
        self._json["responsible_user_id"] = responsible_user_id

    def get_responsible_user_id(self):
        return self._json.get("responsible_user_id")

    def set_group_id(self, group_id:str):
        self._json["group_id"] = group_id

    def get_group_id(self):
        return self._json.get("group_id")

    def set_created_by(self, created_by:str):
        self._json["created_by"] = created_by

    def get_created_by(self):
        return self._json.get("created_by")

    def set_updated_by(self, updated_by:str):
        self._json["updated_by"] = updated_by

    def get_updated_by(self):
        return self._json.get("updated_by")

    def set_created_at(self, created_at:str):
        self._json["created_at"] = created_at

    def get_created_at(self):
        return self._json.get("created_at")

    def set_updated_at(self, updated_at:str):
        self._json["updated_at"] = updated_at

    def get_updated_at(self):
        return self._json.get("updated_at")

    def set_is_deleted(self, is_deleted:str):
        self._json["is_deleted"] = is_deleted

    def get_is_deleted(self):
        return self._json.get("is_deleted")

    def set_closest_task_at(self, closest_task_at:str):
        self._json["closest_task_at"] = closest_task_at

    def get_closest_task_at(self):
        return self._json.get("closest_task_at")

    def set_account_id(self, account_id:str):
        self._json["account_id"] = account_id

    def get_account_id(self):
        return self._json.get("account_id")

    def set_custom_field(self, id:int, values):
        if not self._json.get("custom_fields_values"):
            self._json["custom_fields_values"] = []
        field = {
            "field_id": id,
            "values": values
        }
        for i in range(0, len(self._json["custom_fields_values"])):
            if self._json["custom_fields_values"][i]["field_id"] == id:
                self._json["custom_fields_values"][i]["values"] = values
                return
        self._json["custom_fields_values"].append(field)
    def get_custom_fiedls(self):
        return self._json.get("custom_fields_values")
    def get_leads(self) -> List["Lead"]:
        if not self._json["_embedded"].get("leads") is None:
            ids = [json_lead["id"] for json_lead in self._json["_embedded"].get("leads")]
            params = {"filter[id][]":ids}
            leads = self._api.get_leads(params=params)
            return leads
        else:
            return []

    def get_tags(self):
        from amoApi.amoEntities.Tag import Tag
        return [Tag(self.api, json_tag) for json_tag in self._json["_embedded"]["tags"]]

    def get_json(self):
        return self._json
    def patch(self):
        return self._api.patch_contact(self)


from amoApi.amoEntities.BaseEnity import BaseEnity
import json


class CustomField(BaseEnity):
    def __init__(self, api = None, json_field:json = {}):
        self._json = json_field
        self._api = api

    def from_json(self, json_field:json):
        self._json = json_field
        return self

    def get_json(self):
        return self._json

    def get_id(self) -> int:
        return self._json.get("id")

    def set_id(self, id:int):
        self._json["id"] = id

    def get_type(self) -> str:
        return self._json.get("type")

    def set_type(self, type:str):
        self._json["type"] = type

    def get_name(self) -> str:
        return self._json.get("name")

    def set_name(self, name:str):
        self._json["name"] = name

    def get_code(self) -> str:
        return self._json.get("code")

    def set_code(self, code:str):
        self._json["code"] = code

    def get_sort(self):
        return self._json.get("sort")

    def set_sort(self, sort:int):
        self._json["sort"] = sort

    def get_group_id(self) -> int:
        return self._json.get("group_id")

    def set_group_id(self, group_id:int):
        self._json["group_id"] = group_id

    def is_api_only(self):
        return self._json.get("is_api_only")